Package: lmdme
Type: Package
Title: Linear Model decomposition for Designed Multivariate Experiments
Version: 1.53.0
Date: 2014-01-31
Author: Cristobal Fresno and Elmer A. Fernandez
Maintainer: Cristobal Fresno <cfresno@bdmg.com.ar>
Description: linear ANOVA decomposition of Multivariate Designed
        Experiments implementation based on limma lmFit. Features:
        i)Flexible formula type interface, ii) Fast limma based
        implementation, iii) p-values for each estimated coefficient
        levels in each factor, iv) F values for factor effects and v)
        plotting functions for PCA and PLS.
License: GPL (>=2)
URL: http://www.bdmg.com.ar/?page_id=38
Imports: stats, methods, limma
Depends: R (>= 2.14.1), pls, stemHypoxia
Enhances: parallel
Collate: 'lmdme-Class.R' 'lmdme-lmdme.R' 'lmdme-getters.R'
        'lmdme-printshow.R' 'lmdme-padjust.R' 'lmdme-leverage.R'
        'lmdme-permutation.R' 'lmdme-decomposition.R' 'lmdme-biplot.R'
        'lmdme-screeplot.R' 'lmdme-loadingplot.R'
biocViews: Microarray, OneChannel, TwoChannel, Visualization,
        DifferentialExpression, ExperimentData, Cancer
git_url: https://git.bioconductor.org/packages/lmdme
git_branch: devel
git_last_commit: 885461c
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.23
Date/Publication: 2025-10-30
NeedsCompilation: no
Packaged: 2025-10-30 21:43:43 UTC; biocbuild
